==> huaweicloudsdkmoderation-3.1.141-py2.py3-none-any.whl: huaweicloudsdkmoderation/v3/model/batch_check_image_sync_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchCheckImageSyncResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'request_id': 'str',
        'results': 'list[ImageBatchSyncDetectionResult]'
    }

    attribute_map = {
        'request_id': 'request_id',
        'results': 'results'
    }

    def __init__(self, request_id=None, results=None):
        """BatchCheckImageSyncResponse

        The model defined in huaweicloud sdk

        :param request_id: 本次请求的唯⼀标识，⽤于问题排查，建议保存。
        :type request_id: str
        :param results: 调用结果。
        :type results: list[:class:`huaweicloudsdkmoderation.v3.ImageBatchSyncDetectionResult`]
        """
        
        super(BatchCheckImageSyncResponse, self).__init__()

        self._request_id = None
        self._results = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if results is not None:
            self.results = results

    @property
    def request_id(self):
        """Gets the request_id of this BatchCheckImageSyncResponse.

        本次请求的唯⼀标识，⽤于问题排查，建议保存。

        :return: The request_id of this BatchCheckImageSyncResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this BatchCheckImageSyncResponse.

        本次请求的唯⼀标识，⽤于问题排查，建议保存。

        :param request_id: The request_id of this BatchCheckImageSyncResponse.
        :type request_id: str
        """
        self._request_id = request_id

    @property
    def results(self):
        """Gets the results of this BatchCheckImageSyncResponse.

        调用结果。

        :return: The results of this BatchCheckImageSyncResponse.
        :rtype: list[:class:`huaweicloudsdkmoderation.v3.ImageBatchSyncDetectionResult`]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this BatchCheckImageSyncResponse.

        调用结果。

        :param results: The results of this BatchCheckImageSyncResponse.
        :type results: list[:class:`huaweicloudsdkmoderation.v3.ImageBatchSyncDetectionResult`]
        """
        self._results = results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchCheckImageSyncResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmoderation-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmoderation/v3/model/batch_check_image_sync_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchCheckImageSyncResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'request_id': 'str',
        'results': 'list[ImageBatchSyncDetectionResult]'
    }

    attribute_map = {
        'request_id': 'request_id',
        'results': 'results'
    }

    def __init__(self, request_id=None, results=None):
        r"""BatchCheckImageSyncResponse

        The model defined in huaweicloud sdk

        :param request_id: 本次请求的唯⼀标识，⽤于问题排查，建议保存。
        :type request_id: str
        :param results: 调用结果。
        :type results: list[:class:`huaweicloudsdkmoderation.v3.ImageBatchSyncDetectionResult`]
        """
        
        super(BatchCheckImageSyncResponse, self).__init__()

        self._request_id = None
        self._results = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if results is not None:
            self.results = results

    @property
    def request_id(self):
        r"""Gets the request_id of this BatchCheckImageSyncResponse.

        本次请求的唯⼀标识，⽤于问题排查，建议保存。

        :return: The request_id of this BatchCheckImageSyncResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        r"""Sets the request_id of this BatchCheckImageSyncResponse.

        本次请求的唯⼀标识，⽤于问题排查，建议保存。

        :param request_id: The request_id of this BatchCheckImageSyncResponse.
        :type request_id: str
        """
        self._request_id = request_id

    @property
    def results(self):
        r"""Gets the results of this BatchCheckImageSyncResponse.

        调用结果。

        :return: The results of this BatchCheckImageSyncResponse.
        :rtype: list[:class:`huaweicloudsdkmoderation.v3.ImageBatchSyncDetectionResult`]
        """
        return self._results

    @results.setter
    def results(self, results):
        r"""Sets the results of this BatchCheckImageSyncResponse.

        调用结果。

        :param results: The results of this BatchCheckImageSyncResponse.
        :type results: list[:class:`huaweicloudsdkmoderation.v3.ImageBatchSyncDetectionResult`]
        """
        self._results = results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchCheckImageSyncResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
